@@ -30,5 +30,5 @@ from toolchest_client.api.query import Query
 from toolchest_client.api.status import Status, get_status
 from toolchest_client.api.urls import get_api_url, set_api_url
 from .tools.api import add_database, alphafold, blastn, bowtie2, bracken, cellranger_count, clustalo, demucs,\
-    diamond_blastp, diamond_blastx, humann3, kraken2, lug, megahit, python3, rapsearch, rapsearch2, salmon, shi7, \
-    shogun_align, shogun_filter, STAR, test, transfer, unicycler, update_database
+    diamond_blastp, diamond_blastx, fastqc, humann3, kallisto, kraken2, lastal5, lug, megahit, metaphlan, python3, \
+    rapsearch, rapsearch2, salmon, shi7, shogun_align, shogun_filter, STAR, test, transfer, unicycler, update_database
