@@ -76,8 +76,8 @@ class Query:
     def run_query(self, tool_name, tool_version, input_prefix_mapping,
                   output_type, tool_args=None, database_name=None, database_version=None,
                   remote_database_path=None, remote_database_primary_name=None, input_files=None,
-                  is_database_update=False, database_primary_name=None, output_path=None, output_primary_name=None,
-                  skip_decompression=False, thread_statuses=None, custom_docker_image_id=None,
+                  input_is_compressed=False, is_database_update=False, database_primary_name=None, output_path=None,
+                  output_primary_name=None, skip_decompression=False, thread_statuses=None, custom_docker_image_id=None,
                   instance_type=None, volume_size=None):
         """Executes a query to the Toolchest API.
 
@@ -89,6 +89,8 @@ class Query:
         :param remote_database_path: Path (S3 URI) to a custom database.
         :param remote_database_primary_name: Primary name (i.e. common prefix) of S3 custom database.
         :param custom_docker_image_id: Image id of a custom docker image on the local machine.
+        :param input_is_compressed: Whether the input file is a compressed archive of local files.
+            Only used in cases where a single input is given.
         :param input_prefix_mapping: Mapping of input filepaths to associated prefix tags (e.g., "-1").
         :param is_database_update: Whether the call is to update an existing database.
         :param database_primary_name: Name of the file to use as the primary database file,
@@ -106,7 +108,6 @@ class Query:
         self.thread_name = threading.current_thread().getName()
         self.thread_statuses = thread_statuses
         self._check_if_should_terminate()
-
         # Create pipeline segment and task(s).
         # Retrieve query ID and upload URL from initial response.
         create_response = self._send_initial_request(
@@ -153,7 +154,7 @@ class Query:
 
         self._check_if_should_terminate()
         self._update_thread_status(ThreadStatus.UPLOADING)
-        self._upload(input_files, input_prefix_mapping)
+        self._upload(input_files, input_prefix_mapping, input_is_compressed)
         self._upload_docker_image(custom_docker_image_id)
         self._check_if_should_terminate()
 
@@ -236,7 +237,7 @@ class Query:
             print(f"Failed to update size for file: {file_id}", file=sys.stderr)
             raise
 
-    def _register_input_file(self, input_file_path, input_prefix, input_order):
+    def _register_input_file(self, input_file_path, input_prefix, input_order, input_is_compressed):
         register_input_file_url = "/".join([
             self.PIPELINE_SEGMENT_INSTANCE_URL,
             'input-files'
@@ -248,6 +249,8 @@ class Query:
         if input_is_http_url:
             url_path = urlparse(input_file_path).path
             file_name = os.path.basename(url_path)
+        if input_is_in_s3:
+            file_name = os.path.basename(input_file_path.rstrip("/"))
         response = requests.post(
             register_input_file_url,
             headers=self.HEADERS,
@@ -258,6 +261,7 @@ class Query:
                 "s3_uri": input_file_path if input_is_in_s3 else None,
                 "http_url": input_file_path if input_is_http_url else None,
                 "ftp_url": input_file_path if input_is_ftp_url else None,
+                "is_compressed": input_is_compressed,
             },
         )
         try:
@@ -277,7 +281,7 @@ class Query:
                 "file_id": response_json.get('file_id'),
             }
 
-    def _upload(self, input_file_paths, input_prefix_mapping):
+    def _upload(self, input_file_paths, input_prefix_mapping, input_is_compressed):
         """Uploads the files at ``input_file_paths`` to Toolchest."""
 
         self._update_status(Status.TRANSFERRING_FROM_CLIENT)
@@ -296,6 +300,7 @@ class Query:
                     input_file_path=file_path,
                     input_prefix=input_prefix,
                     input_order=input_order,
+                    input_is_compressed=input_is_compressed,
                 )
             else:
                 print(f"Uploading {file_path}")
@@ -303,6 +308,7 @@ class Query:
                     input_file_path=file_path,
                     input_prefix=input_prefix,
                     input_order=input_order,
+                    input_is_compressed=input_is_compressed,
                 )
 
                 try:
@@ -334,10 +340,11 @@ class Query:
             client = docker.from_env()
             image = client.images.get(custom_docker_image_id)
         except ImageNotFound:
-            raise ToolchestException(f"Unable to find image {custom_docker_image_id}.")
+            return
         except (APIError, DockerException):
-            raise EnvironmentError('Unable to connect to Docker. Make sure yoe have docker installed and that it is '
-                                   'currently running.')
+            print('Unable to connect to Docker. Assuming image is accessible in a registry. If the image is hosted '
+                  'locally start Docker and retry.')
+            return
         register_input_file_url = "/".join([
             self.PIPELINE_SEGMENT_INSTANCE_URL,
             'docker-image'
@@ -373,10 +380,25 @@ class Query:
             )
             docker_image_name_and_tag = custom_docker_image_id.split(':')
             docker_tag = docker_image_name_and_tag[1] if len(docker_image_name_and_tag) > 1 else 'latest'
-            image.tag(f"{registry}/{aws_info['repository_name']}:{docker_tag}", docker_tag)
-            push_output = client.api.push(f"{registry}/{aws_info['repository_name']}:{docker_tag}", docker_tag)
-            if 'errorDetail' in push_output:
-                raise ToolchestJobError("Failed to push image.")
+            image_id = f"{registry}/{aws_info['repository_name']}:{docker_tag}"
+            image.tag(image_id, docker_tag)
+            push_output = client.api.push(
+                image_id,
+                tag=docker_tag,
+                stream=True,
+                decode=True,
+            )
+            for update in push_output:
+                if 'errorDetail' in update:
+                    raise ToolchestJobError("Failed to push image.")
+                # Print doesn't work on some consoles, like the JetBrains suite
+                sys.stdout.write(
+                    "\r{} {}".format(
+                        update.get("status", ""),
+                        update.get("progress", ""),
+                    ).ljust(120),
+                )
+                sys.stdout.flush()
         except APIError:
             raise EnvironmentError('Unable to access ECR at this time. '
                                    'Contact Toolchest support if this error persists')
