@@ -7,10 +7,14 @@ from .cellranger import CellRangerCount
 from .clustalo import ClustalO
 from .demucs import Demucs
 from .diamond import DiamondBlastp, DiamondBlastx
+from .fastqc import FastQC
 from .humann import HUMAnN3
+from .kallisto import Kallisto
 from .kraken2 import Kraken2
+from .last import Lastal5
 from .lug import Lug
 from .megahit import Megahit
+from .metaphlan import MetaPhlAn
 from .python3 import Python3
 from .rapsearch2 import Rapsearch2
 from .salmon import Salmon
